<?php

namespace Drupal\mcapi_bursers\Plugin\Field\FieldType;

use Drupal\Core\Field\EntityReferenceFieldItemList;
use Drupal\user\UserInterface;

/**
 * Represents a Burser reference field list
 */
class BurserReferenceFieldItemList extends EntityReferenceFieldItemList {

  /**
   * {@inheritdoc}
   */
  public function setValue($values, $notify = TRUE) {
    // Support passing in only the value of the first item, either as a literal
    // (value of the first property) or as an array of properties.
    if (isset($values) && (!is_array($values) || (!empty($values) && !is_numeric(current(array_keys($values)))))) {
      $values = [$values];
    }

    // If the first value is not the wallet's owner, then shunt it in.
    $walletOwnerId = $this->getEntity()->getOwnerId();
    foreach ($values as $delta => $value) {
      if ($value['target_id'] == $walletOwnerId) {
        unset($values[$delta]);
        \Drupal::messenger()->addWarning($this->t("Wallet holder @name has been removed as a burser.", ['@name' => '@todo']));
        break;
      }
    }
    $this->unique($values);
    parent::setValue($values, $notify);
  }

  /**
   * Remove any duplicates.
   * @param array $array
   */
  private function unique(&$array) {
    foreach ($array as $key => $item) {
      if (!in_array($item->target_id, $ids)) {
        $ids[] = $item->target_id;
      }
      else unset($array[$key]);
    }
  }

  /**
   * @param \Drupal\mcapi_bursers\Plugin\Field\FieldType\UserInterface $account
   *
   * @return \Drupal\Core\TypedData\TypedDataInterface
   *   The item that was appended.
   */
  public function addBurser(UserInterface $account) {
    $this->appendItem(['target_id' => $account->id()]);
    $this->unique($this->list);
  }


  /**
   * {@inheritdoc}
   *
   * The default value is the wallet owner
   *
   * @note On new wallets this didn't work because we can't getEntity() while it
   * is still being created.
   */
  public function applyDefaultValue($notify = TRUE) {
    if ($this->parent) {
      $wallet = $this->getEntity();
      $entity_type = $wallet->holder_entity_type->value;
      if ($entity_type != 'user') {
        $target_entity_id = \Drupal::entityTypeManager()
          ->getStorage($entity_type)
          ->load($wallet->holder_entity_id->value)
          ->getOwnerId();
      }
      else {
        $target_entity_id = $wallet->holder_entity_id->value;
      }
      parent::setValue(['target_id' => $target_entity_id], $notify);
      \Drupal::messenger()->addWarning("Applying default burser value ($target_entity_id) to wallet ".$wallet->label());
    }
    return $this;
  }

}
