<?php

namespace Drupal\mcapi_forms\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\migrate\Event\MigratePreRowSaveEvent;
use Drupal\migrate\MigrateSkipRowException;

/**
 * Subscriber to create a router item for each transaction form display.
 */
class MigrationSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'migrate.pre_row_save' => [['migratePreRowSave']]
    ];
  }

  /**
   *
   * @param MigratePreRowSaveEvent $event
   */
  public function migratePreRowSave(MigratePreRowSaveEvent $event) {
    $row = $event->getRow();
    switch ($event->getMigration()->id()) {
      case 'd7_filter_format':
        if ($row->getSourceProperty('format') == 'mcapiform_string_format') {
          return new MigrateSkipRowException('Deprecated filter format');
        }
        break;
      case 'd7_mcapi_form':
        $properties = $row->getSource();
        if ($properties['perspective'] == 3) {
          throw new MigrateSkipRowException('Not migrating 3rdparty transaction forms.');
        }
        elseif (strpos($properties['experience']->template, '[mcapiform:direction]')) {
          throw new MigrateSkipRowException('Not migrating 1stparty transaction forms showing the direction widget');
        }
        break;
      case 'd7_menu_links':
        $link_path = $row->getSourceProperty('link_path');
        if ($link_path == 'transact/3rdparty')   {
          $row->setSourceProperty('link_path', 'transaction/create');
        }
        if ($link_path == 'transact/1stparty')   {
          $row->setSourceProperty('link_path', 'transact/credit');
        }
    }
  }
}
