<?php

namespace Drupal\mcapi_forms;

use Drupal\mcapi\Form\TransactionForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\Entity\EntityFormMode;
use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\mcapi\Entity\Storage\WalletStorage;

/**
 * Form builder for transaction formed designed via the UI.
 */
class FirstPartyTransactionForm extends TransactionForm {

  /**
   * The thirdparty settings on the entityForm
   */
  protected $settings;

  /**
   * Constructor.
   */
  public function __construct($entity_repository, $entity_type_bundle_info, $time, $tempstore, $current_request, $current_user, $logger_channel) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time, $tempstore, $current_request, $current_user, $logger_channel);
    $options = $current_request
      ->attributes->get('_route_object')
      ->getOptions();
    $mode = $options['parameters']['mode'];
    $entityDisplay = EntityFormDisplay::load('mcapi_transaction.mcapi_transaction.' . $mode);
    $this->settings = EntityFormMode::load('mcapi_transaction.'.$mode)
      ->getThirdPartySettings('mcapi_forms');
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['#twig_template'] = str_replace(PHP_EOL, "<br/>", $this->settings['experience_twig']);
    $form['#attached']['library'][] = 'mcapi_forms/display';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = $this->settings['experience_button'];
//    $preview_mode = $this->settings['experience_preview'];
//
//    if ($preview_mode != TransactionActionBase::CONFIRM_NORMAL) {
//      $actions['submit']['#attached']['library'][] = 'core/drupal.ajax';
//      if ($preview_mode == TransactionActionBase::CONFIRM_MODAL) {
//        $actions['submit']['#attributes'] = [
//          'class' => ['use-ajax'],
//          'data-accepts' => 'application/vnd.drupal-modal',
//          'data-dialog-options' => Json::encode(['width' => 500]),
//        ];
//      }
//      elseif ($preview_mode == TransactionActionBase::CONFIRM_AJAX) {
//        // Curious how, to make a ajax link, must put the url in 2 places.
//        $actions['submit']['#ajax'] = [
//          'wrapper' => 'mcapi-transaction-1stparty-form',
//          'method' => 'replace',
//          'url' => Url::fromRoute('mcapi.1stparty.' . $this->mode),
//        ];
//      }
//    }
    // @todo check this is working.
    $form['#cache']['contexts'][] = 'user';

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'first_party_transaction_form';
  }

  /**
   * {@inheritdoc}
   */
  public function title() {
    return $this->settings['title'];
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $this->request->query->add(['type' => $this->settings['transaction_type']]);
    return parent::getEntityFromRouteMatch($route_match, $entity_type_id);
  }

  /**
   * {@inheritdoc}
   *
   * Fill in any wallet values not explicitly stated.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->getValue('payee')) {
       $form_state->setValue('payee', WalletStorage::firstWalletOfEntity());
    }
    elseif (!$form_state->getValue('payer')) {
       $form_state->setValue('payer', WalletStorage::firstWalletOfEntity());
    }
    // See https://www.drupal.org/forum/support/module-development-and-code-questions/2018-02-08/required-fields-and-not-null-database
    if (!$form_state->getValue('description')) {
       $form_state->setValue('description', ' ');
    }

    parent::validateForm($form, $form_state);
  }

}
