<?php

namespace Drupal\mcapi\Controller;

use Drupal\mcapi\Entity\Storage\WalletStorage;
use Drupal\Core\Controller\ControllerBase;
use \Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Drupal\Core\Routing\RouteMatchInterface;

/**
 * Returns all the wallets held by the given entity, in summary view mode.
 *
 * @note Only applicable when mcapi.settings config value wallet_tab is TRUE
 */
class WalletController extends ControllerBase {

  /**
   * @var ContentEntityType
   */
  private $holder;

  /**
   * @param RouteMatchInterface $route_match
   */
  public function __construct(RouteMatchInterface $route_match) {
    $params = $route_match->getParameters()->all();
    $this->holder = reset($params);
  }

  /**
   * @param ContainerInterface $container
   * @return \static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_route_match')
    );
  }

  /**
   * Get the name of the wallet(s) holder.
   *
   * @return TranslatableMarkup
   *   The entity label of the wallet holder.
   */
  public function entityWalletsTitle() : TranslatableMarkup {
    return $this->t('Wallet: @name', ['@name' => $this->holder->label()]);
  }

  /**
   * Router callback.
   *
   * Show all an entities wallets in summary mode.
   * this is rather tricky because we don't know what arguments would be passed
   * from the url, so we have to load them from scratch.
   *
   * @return array
   *   A renderable array.
   */
  public function entityWallets() {
    $wallets = WalletStorage::walletsOf($this->holder, TRUE);
    return $this->entityTypeManager()
      ->getViewBuilder('mcapi_wallet')
      ->viewMultiple($wallets);
  }

}
