<?php

namespace Drupal\mcapi\Entity\Storage;

use Drupal\mcapi\Entity\Wallet;
use Drupal\user\Entity\User;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;


/**
 * Storage controller for wallet entity.
 */
class WalletStorage extends SqlContentEntityStorage implements WalletStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function getQueryServiceName() {
    return 'mcapi_wallet.query.sql';
  }

  /**
   * {@inheritdoc}
   */
  public static function walletsOf(ContentEntityInterface $entity, $load = FALSE) {
    $wids = \Drupal::entityQuery('mcapi_wallet')
      ->condition('holder_entity_type', $entity->getEntityTypeId())
      ->condition('holder_entity_id', $entity->id())
      ->execute();
    return $load ?
      Wallet::loadMultiple($wids) :
      $wids;
  }

  /**
   * Return the first wallet held by a given entity.
   *
   * @param ContentEntityBase $entity
   *   Defaults to the current user.
   * @return int
   *   0 if no wallets are held
   */
  static function firstWalletOfEntity(ContentEntityInterface $entity = NULL) : int {
    if (!$entity) {
      $entity = User::load(\Drupal::currentUser()->id());
    }
    if ($wids = self::walletsOf($entity)) {
      return reset($wids);
    }
    return 0;
  }

}

