<?php

namespace Drupal\mcapi\Entity\ViewBuilder;

use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Render controller for wallets.
 */
class WalletViewBuilder extends EntityViewBuilder {

  /**
   * {@inheritdoc}
   *
   * @note For multiple nice wallets see theme callback 'mcapi_wallets'.
   */
  protected function getBuildDefaults(EntityInterface $entity, $view_mode) {
    $build = parent::getBuildDefaults($entity, $view_mode);
    // Add the css.
    $build['#attached'] = ['library' => ['mcapi/mcapi.wallets']];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function buildComponents(array &$build, array $entities, array $displays, $view_mode) {
    parent::buildComponents($build, $entities, $displays, $view_mode);
    $display = $displays['mcapi_wallet'];
    foreach ($entities as $key => $wallet) {
      $extra = mcapi_entity_extra_field_info()['mcapi_wallet']['mcapi_wallet']['display'];
      foreach (['balances', 'balance_bars', 'stats'] as $component) {
        if ($info = $display->getComponent($component)) {
          $build[$key][$component] = [
            '#title' => t('Wallet: %name', ['%name' => $extra[$component]['label']]),
            '#theme' => 'wallet_' . $component,
            '#wallet' => $wallet,
            '#attributes' => ['class' => ['component', $component]],
            '#theme_wrappers' => ['mcapi_wallet_component'],
            '#weight' => $info['weight'],
          ];
        }
      }
      if ($info = $display->getComponent('histories')) {
        $build[$key][$component] = [
        // Only used if we add theme wrappers.
          '#title' => $this->t('Balance history'),
          '#type' => 'balance_histories',
          '#wallet' => $wallet,
          '#attributes' => ['class' => ['component', $component]],
          '#weight' => $info['weight'],
          '#width' => 300,
        ];
      }
      if ($info = $display->getComponent('link_income_expenditure')) {
        $build[$key]['link_income_expenditure'] = [
          '#type' => 'link',
          '#title' => $this->t('Income & Expenditure'),
          '#url' => Url::fromRoute('view.income_expenditure.wallet_page', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $info['weight'],
        ];
        // views_embed_view('income_expenditure', 'income_embed',$wallet->id());
      }
      if ($info = $display->getComponent('link_transactions')) {
        $build[$key]['link_transactions'] = [
          '#type' => 'link',
          '#title' => $this->t('View transactions'),
          '#url' => Url::fromRoute('view.wallet_transactions.wallet_page', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $info['weight'],
        ];
      }
      if ($info = $display->getComponent('canonical_link')) {
        $build[$key]['canonical_link'] = [
          '#type' => 'link',
          '#title' => $this->t('more...'),
          '#url' => Url::fromRoute('entity.mcapi_wallet.canonical', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => ['wallet-link']],
          '#weight' => $info['weight'],
        ];
      }
    }
  }

}
