<?php

namespace Drupal\mcapi\Plugin\TransactionRelative;

use Drupal\mcapi\Plugin\TransactionRelativeInterface;
use Drupal\mcapi\Entity\TransactionInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Database\Query\AlterableInterface;
use Drupal\Core\Database\Query\Condition;

/**
 * Defines a payee relative to a Transaction entity.
 *
 * @TransactionRelative(
 *   id = "payee",
 *   label = @Translation("Owner of payee wallet"),
 *   description = @Translation("The owner of the payee wallet")
 * )
 */
class Payee extends PluginBase implements TransactionRelativeInterface {

  /**
   * {@inheritdoc}
   */
  public function isRelative(TransactionInterface $transaction, AccountInterface $account) {
    return $transaction->payee->entity->getOwner()->id() == $account->id();
  }

  /**
   * {@inheritdoc}
   */
  public function entityViewsCondition(AlterableInterface $query, Condition $or_group, $uid) {
    foreach ($query->getTables() as $alias => $table) {
      if ($table['table'] == 'mcapi_transaction') {
        $this->joinWalletTofield($query, $table['alias'].'.payee');
        $or_group->condition('payer_user.uid', $uid);
      }
      elseif ($table['table'] == 'mcapi_transactions_index') {
        $this->joinWalletTofield($query, $table['alias'].'.uid1');
        $or_group->condition('payer_user.uid', $uid);
      }
      break;
    }
  }

  private function joinWalletTofield($query, $field_alias){
    $query->join('mcapi_wallet', 'payee_wallet', "$field_alias = payee_wallet.wid");
    $query->join('users', 'payee_user', "payee_wallet.holder_entity_id = payee_user.uid AND payee_wallet.holder_entity_type = 'user'");
  }

  /**
   * {@inheritdoc}
   */
  public function getUsers(TransactionInterface $transaction) {
    return [$transaction->payee->entity->getOwner()->id()];
  }

}
